@@ -552,8 +552,9 @@ HEADER
 
                     # Deparse the block of the method/function
                     {
-                        local $self->{function} = refaddr($block);
-                        local $self->{parent_name} = [$obj->{type}, "$obj->{class}::$name"];
+                        local $self->{function}          = refaddr($block);
+                        local $self->{parent_name}       = [$obj->{type}, $name];
+                        local $self->{current_namespace} = $obj->{class};
                         push @{$self->{function_declarations}}, [$self->{function}, "my \$$obj->{name}$refaddr;"];
 
                         if ($self->{ref_class}) {
@@ -637,7 +638,7 @@ HEADER
                         else {
                             $code .= ";"
                               . "state\$_$refaddr=do{no strict 'refs';"
-                              . "CORE::push(\@$self->{package_name}::__SIDEF_CLASS_METHODS__, \$$obj->{name}$refaddr);"
+                              . "\$$self->{package_name}::__SIDEF_CLASS_METHODS__{'$name'} = \$$obj->{name}$refaddr;"
                               . '*{'
                               . $self->_dump_string("$self->{package_name}::$name")
                               . "}=sub{\$$obj->{name}$refaddr->call(\@_)}}";
@@ -921,7 +922,11 @@ HEADER
                         }
 
                         if (exists $self->{class_name}) {
-                            $code .= ',' . 'class=>' . $self->_dump_string($self->{class_name});
+                            $code .= ',class=>' . $self->_dump_string($self->{class_name});
+                        }
+
+                        if ($self->{current_namespace} ne 'main') {
+                            $code .= ',namespace=>' . $self->_dump_string($self->{current_namespace});
                         }
 
                         if (exists($obj->{init_vars}) and @{$obj->{init_vars}{vars}}) {
@@ -1309,7 +1314,7 @@ HEADER
             $code = $self->make_constant($ref, 'new', "Pipe$refaddr", map { $self->_dump_string($_) } @{$obj});
         }
         elsif ($ref eq 'Sidef::Parser') {
-            $code = $self->make_constant($ref, 'new', "Parser$refaddr");
+            $code = '$Sidef::PARSER';
         }
         elsif ($ref eq 'Sidef::Perl::Perl') {
             $code = $self->make_constant($ref, 'new', "Perl$refaddr");
@@ -1366,7 +1371,9 @@ HEADER
         # Method call on the self obj (+optional arguments)
         if (exists $expr->{call}) {
 
+            my $unary;
             my $end = $#{$expr->{call}};
+
             foreach my $i (0 .. $end) {
 
                 my $call   = $expr->{call}[$i];
@@ -1477,8 +1484,11 @@ HEADER
                         next;
                     }
 
-                    # ! prefix-unary
-                    if ($ref eq 'Sidef::Operator::Unary') {
+                    # Unary prefix operator
+                    if ($ref eq 'Sidef::Operator::Unary' and !$unary) {
+
+                        $unary = 1;    # once per call
+
                         if ($method eq '!') {
                             $code = '('
                               . $self->deparse_args(@{$call->{arg}})
