@@ -67,28 +67,26 @@ package Sidef::Types::Block::Block {
 
                 foreach my $class (@isa) {
 
-                    next if index($class, 'Sidef::Runtime') != 0;
+                    (substr($class, 0, 14) eq 'Sidef::Runtime')
+                      || next;
 
-                    my @array = do {
+                    my $method = do {
                         no strict 'refs';
-                        @{$class . '::' . '__SIDEF_CLASS_METHODS__'};
+                        ${$class . '::' . '__SIDEF_CLASS_METHODS__'}{$name};
                     };
 
-                    foreach my $method (@array) {
-                        if ($method->{name} eq $name) {
-                            push @methods, $method;
+                    if (defined($method)) {
+                        push @methods, $method;
 
-                            if (exists($method->{kids})) {
-                                push @methods, @{$method->{kids}};
-                            }
-
-                            if (--$limit == 0) {
-                                die "[ERROR] Too deep or cyclic class inheritance!";
-                            }
-
-                            __SUB__->($method);
-                            last;
+                        if (exists($method->{kids})) {
+                            push @methods, @{$method->{kids}};
                         }
+
+                        if (--$limit == 0) {
+                            die "[ERROR] Too deep or cyclic class inheritance!";
+                        }
+
+                        __SUB__->($method);
                     }
                 }
               }
@@ -237,11 +235,14 @@ package Sidef::Types::Block::Block {
           )
           . ')'
           . "\n\nPossible candidates are: "
-          . "\n    $name("
+          . "\n    "
           . join(
-            ")\n    $name(",
+            "\n    ",
             map {
-                join(
+                    (exists($_->{namespace}) ? ($_->{namespace} . '::') : '')
+                  . (exists($_->{class}) ? (Sidef::normalize_type($_->{class}) . '.') : '')
+                  . Sidef::normalize_type($_->{name}) . '('
+                  . join(
                     ', ',
                     map {
                             (exists($_->{slurpy}) ? '*' : '')
@@ -249,10 +250,11 @@ package Sidef::Types::Block::Block {
                           . $_->{name}
                           . (exists($_->{subset}) ? (' < ' . Sidef::normalize_type($_->{subset})) : '')
                       } @{$_->{vars}}
-                    )
-              } ($self, (exists($self->{kids}) ? @{$self->{kids}} : ()))
+                  )
+                  . ')'
+              } @methods
           )
-          . ")\n\n ";
+          . "\n\n";
     }
 
     sub call {
