@@ -374,6 +374,43 @@ package Sidef::Types::Number::Complex {
 
     *fdiv = \&div;
 
+    sub mod {
+        my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Number') {
+            $y = __PACKAGE__->new($y);
+        }
+        else {
+            _valid(\$y);
+        }
+
+        $x = $$x;
+        $y = $$y;
+
+        my $quo = Math::MPC::Rmpc_init2($PREC);
+        Math::MPC::Rmpc_set($quo, $x, $ROUND);
+        Math::MPC::Rmpc_div($quo, $quo, $y, $ROUND);
+
+        my $real = Math::MPFR::Rmpfr_init2($PREC);
+        my $imag = Math::MPFR::Rmpfr_init2($PREC);
+
+        Math::MPC::RMPC_RE($real, $quo);
+        Math::MPC::RMPC_IM($imag, $quo);
+
+        Math::MPFR::Rmpfr_floor($real, $real);
+        Math::MPFR::Rmpfr_floor($imag, $imag);
+
+        Math::MPC::Rmpc_set_fr_fr($quo, $real, $imag, $ROUND);
+
+        Math::MPC::Rmpc_mul($quo, $quo, $y, $ROUND);
+        Math::MPC::Rmpc_neg($quo, $quo, $ROUND);
+        Math::MPC::Rmpc_add($quo, $quo, $x, $ROUND);
+
+        bless \$quo, __PACKAGE__;
+    }
+
+    *fmod = \&mod;
+
     sub inv {
         my ($x) = @_;
 
@@ -921,6 +958,14 @@ package Sidef::Types::Number::Complex {
         }
     }
 
+    sub _cmp {
+        my ($x, $y) = @_;
+        my $si = Math::MPC::Rmpc_cmp($x, $y);
+        my $re_cmp = Math::MPC::RMPC_INEX_RE($si);
+        $re_cmp == 0 or return $re_cmp;
+        Math::MPC::RMPC_INEX_IM($si);
+    }
+
     sub gt {
         my ($x, $y) = @_;
 
@@ -931,7 +976,12 @@ package Sidef::Types::Number::Complex {
             _valid(\$y);
         }
 
-        $x->abs->gt($y->abs);
+        if (_cmp($$x, $$y) > 0) {
+            (Sidef::Types::Bool::Bool::TRUE);
+        }
+        else {
+            (Sidef::Types::Bool::Bool::FALSE);
+        }
     }
 
     sub ge {
@@ -944,7 +994,12 @@ package Sidef::Types::Number::Complex {
             _valid(\$y);
         }
 
-        $x->abs->ge($y->abs);
+        if (_cmp($$x, $$y) >= 0) {
+            (Sidef::Types::Bool::Bool::TRUE);
+        }
+        else {
+            (Sidef::Types::Bool::Bool::FALSE);
+        }
     }
 
     sub lt {
@@ -957,7 +1012,12 @@ package Sidef::Types::Number::Complex {
             _valid(\$y);
         }
 
-        $x->abs->lt($y->abs);
+        if (_cmp($$x, $$y) < 0) {
+            (Sidef::Types::Bool::Bool::TRUE);
+        }
+        else {
+            (Sidef::Types::Bool::Bool::FALSE);
+        }
     }
 
     sub le {
@@ -970,7 +1030,12 @@ package Sidef::Types::Number::Complex {
             _valid(\$y);
         }
 
-        $x->abs->le($y->abs);
+        if (_cmp($$x, $$y) <= 0) {
+            (Sidef::Types::Bool::Bool::TRUE);
+        }
+        else {
+            (Sidef::Types::Bool::Bool::FALSE);
+        }
     }
 
     sub cmp {
@@ -983,30 +1048,166 @@ package Sidef::Types::Number::Complex {
             _valid(\$y);
         }
 
-        $x->abs->cmp($y->abs);
+        my $i = _cmp($$x, $$y);
+            $i < 0 ? (Sidef::Types::Number::Number::MONE)
+          : $i > 0 ? (Sidef::Types::Number::Number::ONE)
+          :          (Sidef::Types::Number::Number::ZERO);
     }
 
+    sub acmp {
+        my ($x, $y) = @_;
+
+        my $i = do {
+            if (ref($y) eq 'Sidef::Types::Number::Number') {
+                my $n = Math::MPFR::Rmpfr_init2($PREC);
+                Math::MPC::Rmpc_abs($n, $$x, $ROUND);
+                Math::MPFR::Rmpfr_cmpabs($n, $y->_big2mpfr);
+            }
+            else {
+                _valid(\$y);
+                my $n = Math::MPFR::Rmpfr_init2($PREC);
+                my $m = Math::MPFR::Rmpfr_init2($PREC);
+                Math::MPC::Rmpc_abs($n, $$x, $ROUND);
+                Math::MPC::Rmpc_abs($m, $$y, $ROUND);
+                Math::MPFR::Rmpfr_cmpabs($n, $m);
+            }
+        };
+            $i < 0 ? (Sidef::Types::Number::Number::MONE)
+          : $i > 0 ? (Sidef::Types::Number::Number::ONE)
+          :          (Sidef::Types::Number::Number::ZERO);
+    }
+
+    #
+    ## sgn(x) = x / abs(x)
+    #
+
+    sub sign {
+        my ($x) = @_;
+
+        my $abs = Math::MPFR::Rmpfr_init2($PREC);
+        Math::MPC::Rmpc_abs($abs, $$x, $ROUND);
+
+        if (Math::MPFR::Rmpfr_zero_p($abs)) {    # it's zero
+            return (Sidef::Types::Number::Number::ZERO);
+        }
+
+        my $r = Math::MPC::Rmpc_init2($PREC);
+        Math::MPC::Rmpc_div_fr($r, $$x, $abs, $ROUND);
+        bless \$r, __PACKAGE__;
+    }
+
+    *sgn = \&sign;
+
     sub floor {
-        $_[0]->abs->floor;
+        my ($x) = @_;
+
+        my $real = Math::MPFR::Rmpfr_init2($PREC);
+        my $imag = Math::MPFR::Rmpfr_init2($PREC);
+
+        Math::MPC::RMPC_RE($real, $$x);
+        Math::MPC::RMPC_IM($imag, $$x);
+
+        Math::MPFR::Rmpfr_floor($real, $real);
+        Math::MPFR::Rmpfr_floor($imag, $imag);
+
+        if (Math::MPFR::Rmpfr_zero_p($imag)) {
+            return Sidef::Types::Number::Number::_mpfr2big($real);
+        }
+
+        my $r = Math::MPC::Rmpc_init2($PREC);
+        Math::MPC::Rmpc_set_fr_fr($r, $real, $imag, $ROUND);
+        bless \$r, __PACKAGE__;
     }
 
     sub ceil {
-        $_[0]->abs->ceil;
+        my ($x) = @_;
+
+        my $real = Math::MPFR::Rmpfr_init2($PREC);
+        my $imag = Math::MPFR::Rmpfr_init2($PREC);
+
+        Math::MPC::RMPC_RE($real, $$x);
+        Math::MPC::RMPC_IM($imag, $$x);
+
+        Math::MPFR::Rmpfr_ceil($real, $real);
+        Math::MPFR::Rmpfr_ceil($imag, $imag);
+
+        if (Math::MPFR::Rmpfr_zero_p($imag)) {
+            return Sidef::Types::Number::Number::_mpfr2big($real);
+        }
+
+        my $r = Math::MPC::Rmpc_init2($PREC);
+        Math::MPC::Rmpc_set_fr_fr($r, $real, $imag, $ROUND);
+        bless \$r, __PACKAGE__;
+    }
+
+    sub _round {
+        my ($n, $nth) = @_;
+
+        my $p = Math::MPFR::Rmpfr_init2($PREC);
+        Math::MPFR::Rmpfr_set_str($p, '1e' . CORE::abs($nth), 10, $Sidef::Types::Number::Number::ROUND);
+
+        if ($nth < 0) {
+            Math::MPFR::Rmpfr_div($n, $n, $p, $Sidef::Types::Number::Number::ROUND);
+        }
+        else {
+            Math::MPFR::Rmpfr_mul($n, $n, $p, $Sidef::Types::Number::Number::ROUND);
+        }
+
+        Math::MPFR::Rmpfr_round($n, $n);
+
+        if ($nth < 0) {
+            Math::MPFR::Rmpfr_mul($n, $n, $p, $Sidef::Types::Number::Number::ROUND);
+        }
+        else {
+            Math::MPFR::Rmpfr_div($n, $n, $p, $Sidef::Types::Number::Number::ROUND);
+        }
     }
 
     sub round {
         my ($x, $prec) = @_;
-        $x->abs->round(defined($prec) ? $prec : ());
+
+        my $nth = (
+            defined($prec)
+            ? do {
+                Sidef::Types::Number::Number::_valid(\$prec);
+                -CORE::int(Math::GMPq::Rmpq_get_d($$prec));
+              }
+            : 0
+        );
+
+        my $real = Math::MPFR::Rmpfr_init2($PREC);
+        my $imag = Math::MPFR::Rmpfr_init2($PREC);
+
+        Math::MPC::RMPC_RE($real, $$x);
+        Math::MPC::RMPC_IM($imag, $$x);
+
+        _round($real, $nth);
+        _round($imag, $nth);
+
+        if (Math::MPFR::Rmpfr_zero_p($imag)) {
+            return Sidef::Types::Number::Number::_mpfr2big($real);
+        }
+
+        my $r = Math::MPC::Rmpc_init2($PREC);
+        Math::MPC::Rmpc_set_fr_fr($r, $real, $imag, $ROUND);
+        bless \$r, __PACKAGE__;
     }
 
     *roundf = \&round;
 
     sub is_zero {
-        $_[0]->abs->is_zero;
+        $_[0]->imag->is_zero
+          and $_[0]->real->is_zero;
     }
 
     sub is_one {
-        $_[0]->abs->is_one;
+        $_[0]->imag->is_zero
+          and $_[0]->real->is_one;
+    }
+
+    sub is_mone {
+        $_[0]->imag->is_zero
+          and $_[0]->real->is_mone;
     }
 
     sub is_even {
@@ -1024,19 +1225,16 @@ package Sidef::Types::Number::Complex {
         my $im = Math::MPFR::Rmpfr_init2($PREC);
         Math::MPC::Rmpc_imag($im, ${$_[0]}, $ROUND);
 
-        if (Math::MPFR::Rmpfr_sgn($im) != 0) {
+        if (!Math::MPFR::Rmpfr_zero_p($im)) {
             return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         my $re = Math::MPFR::Rmpfr_init2($PREC);
         Math::MPC::Rmpc_real($re, ${$_[0]}, $ROUND);
 
-        if (Math::MPFR::Rmpfr_integer_p($re)) {
-            (Sidef::Types::Bool::Bool::TRUE);
-        }
-        else {
-            (Sidef::Types::Bool::Bool::FALSE);
-        }
+        Math::MPFR::Rmpfr_integer_p($re)
+          ? (Sidef::Types::Bool::Bool::TRUE)
+          : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     # Returns true when the imaginary part is zero
@@ -1045,12 +1243,9 @@ package Sidef::Types::Number::Complex {
         my $im = Math::MPFR::Rmpfr_init2($PREC);
         Math::MPC::Rmpc_imag($im, ${$_[0]}, $ROUND);
 
-        if (Math::MPFR::Rmpfr_sgn($im) == 0) {
-            (Sidef::Types::Bool::Bool::TRUE);
-        }
-        else {
-            (Sidef::Types::Bool::Bool::FALSE);
-        }
+        Math::MPFR::Rmpfr_zero_p($im)
+          ? (Sidef::Types::Bool::Bool::TRUE)
+          : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub is_nan {
@@ -1086,6 +1281,7 @@ package Sidef::Types::Number::Complex {
         *{__PACKAGE__ . '::' . '-'}   = \&sub;
         *{__PACKAGE__ . '::' . '+'}   = \&add;
         *{__PACKAGE__ . '::' . '~'}   = \&not;
+        *{__PACKAGE__ . '::' . '%'}   = \&mod;
     }
 }
 
