@@ -60,12 +60,15 @@ package Sidef::Types::Number::Inf {
 
     sub is_pos { Sidef::Types::Bool::Bool::TRUE }
 
-    *is_inf = \&is_pos;
+    *is_inf      = \&is_pos;
+    *is_positive = \&is_pos;
 
     sub is_real { Sidef::Types::Bool::Bool::FALSE }
 
     *is_nan            = \&is_real;
     *is_neg            = \&is_real;
+    *is_negative       = \&is_real;
+    *is_int            = \&is_real;
     *is_prime          = \&is_real;
     *is_semiprime      = \&is_real;
     *is_prob_prime     = \&is_real;
@@ -146,6 +149,7 @@ package Sidef::Types::Number::Inf {
     *prime_count         = \&nan;
     *square_free_count   = \&nan;
     *remove              = \&nan;
+    *make_coprime        = \&nan;
     *rad                 = \&nan;
     *bessel_j            = \&nan;
     *bessel_y            = \&nan;
@@ -249,8 +253,11 @@ package Sidef::Types::Number::Inf {
     *lngamma          = \&inf;
     *eint             = \&inf;
     *ei               = \&inf;
+    *Ei               = \&inf;
     *li2              = \&ninf;
+    *Li2              = \&ninf;
     *li               = \&inf;
+    *Li               = \&inf;
     *inc              = \&inf;
     *dec              = \&inf;
     *int              = \&inf;
@@ -268,6 +275,9 @@ package Sidef::Types::Number::Inf {
     *fac              = \&inf;
     *double_factorial = \&inf;
     *dfac             = \&inf;
+    *dfactorial       = \&inf;
+    *mfac             = \&inf;
+    *mfactorial       = \&inf;
     *primorial        = \&inf;
     *pn_primorial     = \&inf;
     *fibonacci        = \&inf;
@@ -291,6 +301,10 @@ package Sidef::Types::Number::Inf {
 
     *inv = \&zero;
 
+    *ai   = \&zero;
+    *airy = \&zero;
+    *Ai   = \&zero;
+
     *sin = \&nan;    # -1 to 1
     *cos = \&nan;    # -1 to 1
 
@@ -309,6 +323,7 @@ package Sidef::Types::Number::Inf {
     *eta  = \&tanh;
     *erf  = \&tanh;
     *sign = \&tanh;
+    *sgn  = \&tanh;
 
     sub chr { state $x = Sidef::Types::String::String->new('') }
 
