@@ -58,10 +58,13 @@ package Sidef::Types::Number::Ninf {
 
     sub is_pos { Sidef::Types::Bool::Bool::FALSE }
 
+    *is_positive = \&is_pos;
+
     sub is_neg { Sidef::Types::Bool::Bool::TRUE }
 
-    *is_inf  = \&is_neg;
-    *is_ninf = \&is_neg;
+    *is_inf      = \&is_neg;
+    *is_ninf     = \&is_neg;
+    *is_negative = \&is_neg;
 
     sub nan { Sidef::Types::Number::Nan::NAN }
 
@@ -75,6 +78,9 @@ package Sidef::Types::Number::Ninf {
     *fac              = \&nan;
     *double_factorial = \&nan;
     *dfac             = \&nan;
+    *dfactorial       = \&nan;
+    *mfac             = \&nan;
+    *mfactorial       = \&nan;
     *primorial        = \&nan;
     *pn_primorial     = \&nan;
     *fibonacci        = \&nan;
@@ -236,6 +242,7 @@ package Sidef::Types::Number::Ninf {
     *coth = \&tanh;
     *erf  = \&tanh;
     *sign = \&tanh;
+    *sgn  = \&tanh;
 
     #
     ## -inf.times {} is a no-op
